require 'minitest/autorun'
require_relative '../lib/rails_google_fonts'

describe "setting key" do
  describe "no key being input" do
    it "raises an argument error" do
      proc { RailsGoogleFonts.key }.must_raise ArgumentError
    end
  end

  describe "key is input" do
    it "sets the key sucessfully" do
      RailsGoogleFonts.key('ABC123')[:query][:key].must_equal 'ABC123'
    end
  end
end

describe "key not set" do
  describe "get all fonts" do
    it "raises a key not set error" do
      proc { RailsGoogleFonts.all }.must_raise RuntimeError
    end
  end

  describe "get all fonts sorted in a given order" do
    it "raises an invalid key error" do
      proc { RailsGoogleFonts.all_by("alpha") }.must_raise RuntimeError
    end
  end

    describe "get all fonts filtered by category" do
      it "raises an invalid key error" do
      proc { RailsGoogleFonts.category("serif") }.must_raise RuntimeError
    end
  end
end

describe "invalid key" do
  before do
    RailsGoogleFonts.key("abcABC123")
  end

  describe "get all fonts" do
    it "raises an invalid key error" do
      proc { RailsGoogleFonts.all }.must_raise RuntimeError
    end
  end

  describe "get all fonts sorted in a given order" do
    it "raises an invalid key error" do
      proc { RailsGoogleFonts.all_by("alpha") }.must_raise RuntimeError
    end
  end

  describe "get all fonts filtered by category" do
    it "raises an invalid key error" do
      proc { RailsGoogleFonts.category("serif") }.must_raise RuntimeError
    end
  end
end

describe "valid key" do
  before do
    RailsGoogleFonts.key(ENV["GOOGLE_API_KEY"])
  end

  describe "get all fonts" do
    it "returns all fonts" do
      RailsGoogleFonts.all.must_be_instance_of Array
    end
  end

  describe "get all fonts sorted in a given order" do
    it "returns all fonts sorted in alphabetical order" do
      RailsGoogleFonts.all_by("alpha").must_be_instance_of Array
    end

    it "raises an invalid parameter error" do
      proc { RailsGoogleFonts.all_by("invalid_parameter") }.must_raise RuntimeError
    end
  end

  describe "get all fonts filtered by category" do
    it "returns all fonts in serif category" do
      RailsGoogleFonts.category("serif")[0]["category"].must_equal 'serif'
    end

    it "returns empty array for an invalid category" do
      RailsGoogleFonts.category("invalid_category").must_be_empty
    end
  end
end
